@@ -19,7 +19,7 @@ package v1
 
 import (
 	"encoding/json"
-	"fmt"
+	"errors"
 )
 
 // +kubebuilder:object:generate=false
@@ -74,6 +74,7 @@ func (e *ErrorHandlerNone) Configuration() (map[string]interface{}, error) {
 // ErrorHandlerLog represent a default (log) error handler type.
 type ErrorHandlerLog struct {
 	ErrorHandlerNone
+
 	Parameters *ErrorHandlerParameters `json:"parameters,omitempty"`
 }
 
@@ -102,6 +103,7 @@ func (e *ErrorHandlerLog) Configuration() (map[string]interface{}, error) {
 // ErrorHandlerSink represents a sink error handler type which behave like a dead letter channel.
 type ErrorHandlerSink struct {
 	ErrorHandlerLog
+
 	DLCEndpoint *Endpoint `json:"endpoint,omitempty"`
 }
 
@@ -128,7 +130,8 @@ func (e *ErrorHandlerSink) Configuration() (map[string]interface{}, error) {
 // Validate --.
 func (e *ErrorHandlerSink) Validate() error {
 	if e.DLCEndpoint == nil {
-		return fmt.Errorf("missing endpoint in Error Handler Sink")
+		return errors.New("missing endpoint in Error Handler Sink")
 	}
+
 	return nil
 }
