@@ -54,9 +54,12 @@ type PipeSpec struct {
 	Sink Endpoint `json:"sink,omitempty"`
 	// ErrorHandler is an optional handler called upon an error occurring in the integration
 	ErrorHandler *ErrorHandlerSpec `json:"errorHandler,omitempty"`
+	// the traits needed to customize the depending Integration
+	Traits *Traits `json:"traits,omitempty"`
 	// Steps contains an optional list of intermediate steps that are executed between the Source and the Sink
 	Steps []Endpoint `json:"steps,omitempty"`
 	// Replicas is the number of desired replicas for the Pipe
+	// +kubebuilder:default=1
 	Replicas *int32 `json:"replicas,omitempty"`
 	// Custom SA to use for the Pipe
 	ServiceAccountName string `json:"serviceAccountName,omitempty"`
@@ -156,6 +159,8 @@ const (
 	PipePhaseError PipePhase = "Error"
 	// PipePhaseReady --.
 	PipePhaseReady PipePhase = "Ready"
+	// PipePhaseBuildComplete --.
+	PipePhaseBuildComplete PipePhase = "Build Complete"
 )
 
 // +kubebuilder:object:root=true
@@ -164,5 +169,6 @@ const (
 type PipeList struct {
 	metav1.TypeMeta `json:",inline"`
 	metav1.ListMeta `json:"metadata,omitempty"`
-	Items           []Pipe `json:"items"`
+
+	Items []Pipe `json:"items"`
 }
