@@ -54,7 +54,6 @@ const (
 `
 )
 
-// nolint: unparam
 func initializeRunCmdOptions(t *testing.T) (*runCmdOptions, *cobra.Command, RootCmdOptions) {
 	t.Helper()
 
@@ -65,7 +64,6 @@ func initializeRunCmdOptions(t *testing.T) (*runCmdOptions, *cobra.Command, Root
 	return runCmdOptions, rootCmd, *options
 }
 
-// nolint: unparam
 func initializeRunCmdOptionsWithOutput(t *testing.T) (*runCmdOptions, *cobra.Command, RootCmdOptions) {
 	t.Helper()
 	defaultIntegrationPlatform := v1.NewIntegrationPlatform("default", platform.DefaultPlatformName)
@@ -227,25 +225,6 @@ func TestRunNameFlag(t *testing.T) {
 	assert.Equal(t, "myIntegration", runCmdOptions.IntegrationName)
 }
 
-func TestRunOpenApiFlag(t *testing.T) {
-	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
-	_, err := ExecuteCommand(rootCmd, cmdRun,
-		"--open-api", "configmap:oapi2",
-		integrationSource)
-	require.NoError(t, err)
-	assert.Len(t, runCmdOptions.OpenAPIs, 1)
-	assert.Equal(t, "configmap:oapi2", runCmdOptions.OpenAPIs[0])
-}
-
-func TestRunOpenApiInvalidFlag(t *testing.T) {
-	_, rootCmd, _ := initializeRunCmdOptions(t)
-	_, err := ExecuteCommand(rootCmd, cmdRun,
-		"--open-api", "secret:oapi1",
-		"--open-api", "oapi2",
-		integrationSource)
-	require.Error(t, err)
-}
-
 func TestRunOutputFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := ExecuteCommand(rootCmd, cmdRun, "-o", "yaml", integrationSource)
@@ -458,7 +437,6 @@ func TestConfigureTraits(t *testing.T) {
 	require.NoError(t, err)
 	traitMap, err := trait.ToTraitMap(traits)
 	require.NoError(t, err)
-	assert.Len(t, traits.Addons, 0)
 	assert.Len(t, traitMap, 4)
 	assertTraitConfiguration(t, traits.Affinity, &traitv1.AffinityTrait{PodAffinity: ptr.To(false)})
 	assertTraitConfiguration(t, traits.Environment, &traitv1.EnvironmentTrait{ContainerMeta: ptr.To(false)})
@@ -604,7 +582,6 @@ kind: Integration
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: %s
 spec:
   sources:
@@ -639,7 +616,6 @@ kind: Integration
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: %s
 spec:
   sources:
@@ -947,7 +923,6 @@ kind: Integration
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-app-v1
 spec:
   traits:
@@ -971,7 +946,6 @@ kind: Integration
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-it
 spec:
   git:
@@ -992,7 +966,6 @@ kind: Integration
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-it
 spec:
   git:
@@ -1014,7 +987,6 @@ kind: Integration
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-it
 spec:
   git:
@@ -1036,7 +1008,6 @@ kind: Integration
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-it
 spec:
   git:
