@@ -62,10 +62,10 @@ func (action *buildAction) CanHandle(kit *v1.IntegrationKit) bool {
 }
 
 func (action *buildAction) Handle(ctx context.Context, kit *v1.IntegrationKit) (*v1.IntegrationKit, error) {
-	if kit.Status.Phase == v1.IntegrationKitPhaseBuildSubmitted ||
-		kit.Status.Phase == v1.IntegrationKitPhaseWaitingForCatalog {
+	switch kit.Status.Phase {
+	case v1.IntegrationKitPhaseBuildSubmitted, v1.IntegrationKitPhaseWaitingForCatalog:
 		return action.handleBuildSubmitted(ctx, kit)
-	} else if kit.Status.Phase == v1.IntegrationKitPhaseBuildRunning {
+	case v1.IntegrationKitPhaseBuildRunning:
 		return action.handleBuildRunning(ctx, kit)
 	}
 
@@ -82,7 +82,6 @@ func (action *buildAction) handleBuildSubmitted(ctx context.Context, kit *v1.Int
 		build.Status.Phase == v1.BuildPhaseError ||
 		build.Status.Phase == v1.BuildPhaseInterrupted ||
 		build.Status.Phase == v1.BuildPhaseSucceeded {
-
 		b, err := action.createBuild(ctx, kit)
 		if err != nil {
 			return nil, err
@@ -93,6 +92,7 @@ func (action *buildAction) handleBuildSubmitted(ctx context.Context, kit *v1.Int
 
 	if build.Status.Phase == v1.BuildPhaseRunning {
 		kit.Status.Phase = v1.IntegrationKitPhaseBuildRunning
+
 		return kit, nil
 	}
 
