@@ -120,7 +120,6 @@ func configureRegistry(ctx context.Context, c client.Client, p *v1.IntegrationPl
 	if p.Status.Cluster == v1.IntegrationPlatformClusterOpenShift &&
 		p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyS2I &&
 		p.Status.Build.Registry.Address == "" {
-
 		err := configureForOpenShiftS2i(ctx, c, p)
 		if err != nil {
 			return err
@@ -128,6 +127,7 @@ func configureRegistry(ctx context.Context, c client.Client, p *v1.IntegrationPl
 	}
 
 	log.Debugf("Final Registry Address: %s", p.Status.Build.Registry.Address)
+
 	return nil
 }
 
@@ -305,7 +305,7 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 			Duration: defaultBuildTimeout,
 		}
 	} else {
-		d := p.Status.Build.GetTimeout().Duration.Truncate(time.Second)
+		d := p.Status.Build.GetTimeout().Truncate(time.Second)
 
 		if verbose && p.Status.Build.GetTimeout().Duration != d {
 			log.Log.Infof("Build timeout minimum unit is sec (configured: %s, truncated: %s)", p.Status.Build.GetTimeout().Duration, d)
@@ -319,9 +319,10 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 
 	if p.Status.Build.MaxRunningBuilds <= 0 {
 		log.Debugf("Integration Platform %s [%s]: setting max running builds", p.Name, p.Namespace)
-		if p.Status.Build.BuildConfiguration.Strategy == v1.BuildStrategyRoutine {
+		switch p.Status.Build.BuildConfiguration.Strategy {
+		case v1.BuildStrategyRoutine:
 			p.Status.Build.MaxRunningBuilds = 3
-		} else if p.Status.Build.BuildConfiguration.Strategy == v1.BuildStrategyPod {
+		case v1.BuildStrategyPod:
 			p.Status.Build.MaxRunningBuilds = 10
 		}
 	}
