@@ -18,7 +18,7 @@ limitations under the License.
 package trait
 
 import (
-	"fmt"
+	"errors"
 	"strconv"
 
 	corev1 "k8s.io/api/core/v1"
@@ -124,7 +124,7 @@ func (t *knativeServiceTrait) Apply(e *Environment) error {
 		v1.IntegrationConditionKnativeServiceAvailable,
 		corev1.ConditionTrue,
 		v1.IntegrationConditionKnativeServiceAvailableReason,
-		fmt.Sprintf("Knative service name is %s", ksvc.Name),
+		"Knative service name is "+ksvc.Name,
 	)
 
 	return nil
@@ -140,7 +140,7 @@ func (t *knativeServiceTrait) SelectControllerStrategy(e *Environment) (*Control
 		if ptr.Deref(t.Enabled, false) {
 			// Warn the user that he requested a feature but it cannot be fulfilled due to missing
 			// API installation
-			return nil, fmt.Errorf("missing Knative Service API, cannot enable Knative service trait")
+			return nil, errors.New("missing Knative Service API, cannot enable Knative service trait")
 		}
 		// Fallback to other strategies otherwise
 		return nil, nil
@@ -159,6 +159,7 @@ func (t *knativeServiceTrait) SelectControllerStrategy(e *Environment) (*Control
 	}
 	if enabled {
 		controllerStrategy := ControllerStrategyKnativeService
+
 		return &controllerStrategy, nil
 	}
 
@@ -192,6 +193,10 @@ func (t *knativeServiceTrait) getServiceFor(e *Environment) (*serving.Service, e
 			revisionAnnotations[k] = v
 		}
 	}
+
+	// Set the default container annotation for kubectl
+	revisionAnnotations[defaultContainerAnnotation] = defaultContainerName
+
 	// Set Knative auto-scaling
 	if t.Class != "" {
 		revisionAnnotations[knativeServingClassAnnotation] = t.Class
@@ -255,7 +260,7 @@ func (t *knativeServiceTrait) getServiceFor(e *Environment) (*serving.Service, e
 	}
 
 	if t.TimeoutSeconds != nil {
-		svc.Spec.ConfigurationSpec.Template.Spec.TimeoutSeconds = t.TimeoutSeconds
+		svc.Spec.Template.Spec.TimeoutSeconds = t.TimeoutSeconds
 	}
 	replicas := e.Integration.Spec.Replicas
 
@@ -286,23 +291,16 @@ func (t *knativeServiceTrait) getServiceFor(e *Environment) (*serving.Service, e
 		isUpdateRequired = true
 	}
 
-	//nolint:nestif
 	if isUpdateRequired {
-		if replicas == nil {
-			if t.MinScale != nil && *t.MinScale > 0 {
-				svc.Spec.Template.Annotations[knativeServingMinScaleAnnotation] = strconv.Itoa(*t.MinScale)
-			} else {
-				delete(svc.Spec.Template.Annotations, knativeServingMinScaleAnnotation)
-			}
-			if t.MaxScale != nil && *t.MaxScale > 0 {
-				svc.Spec.Template.Annotations[knativeServingMaxScaleAnnotation] = strconv.Itoa(*t.MaxScale)
-			} else {
-				delete(svc.Spec.Template.Annotations, knativeServingMaxScaleAnnotation)
-			}
+		if t.MinScale != nil && *t.MinScale > 0 {
+			svc.Spec.Template.Annotations[knativeServingMinScaleAnnotation] = strconv.Itoa(*t.MinScale)
 		} else {
-			scale := strconv.Itoa(int(*replicas))
-			svc.Spec.Template.Annotations[knativeServingMinScaleAnnotation] = scale
-			svc.Spec.Template.Annotations[knativeServingMaxScaleAnnotation] = scale
+			delete(svc.Spec.Template.Annotations, knativeServingMinScaleAnnotation)
+		}
+		if t.MaxScale != nil && *t.MaxScale > 0 {
+			svc.Spec.Template.Annotations[knativeServingMaxScaleAnnotation] = strconv.Itoa(*t.MaxScale)
+		} else {
+			delete(svc.Spec.Template.Annotations, knativeServingMaxScaleAnnotation)
 		}
 	}
 
