@@ -81,12 +81,14 @@ func getLanguageSettings(e *Environment, language v1.Language) languageSettings
 		}
 		sourcesRequiredAtBuildTime, sExists := loader.Metadata["sources-required-at-build-time"]
 		deprecated, dpExists := loader.Metadata["deprecated"]
+
 		return languageSettings{
 			native:                     native == boolean.TrueString,
 			sourcesRequiredAtBuildTime: sExists && sourcesRequiredAtBuildTime == boolean.TrueString,
 			deprecated:                 dpExists && deprecated == boolean.TrueString,
 		}
 	}
+
 	return getLegacyLanguageSettings(language)
 }
 
@@ -126,6 +128,7 @@ func (t *quarkusTrait) Matches(trait Trait) bool {
 		if qt.containsMode(md) {
 			continue
 		}
+
 		return false
 	}
 	// We need to check if the native base image used is the same
@@ -176,12 +179,14 @@ func (t *quarkusTrait) adaptDeprecatedFields() *TraitCondition {
 		for _, pt := range t.PackageTypes {
 			if pt == traitv1.NativePackageType {
 				t.Modes = append(t.Modes, traitv1.NativeQuarkusMode)
+
 				continue
 			}
 			if pt == traitv1.FastJarPackageType {
 				t.Modes = append(t.Modes, traitv1.JvmQuarkusMode)
 			}
 		}
+
 		return NewIntegrationCondition("Quarkus", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, TraitConfigurationReason, message)
 	}
 
@@ -215,6 +220,7 @@ func (t *quarkusTrait) validateNativeSupport(e *Environment) error {
 func (t *quarkusTrait) Apply(e *Environment) error {
 	if e.IntegrationInPhase(v1.IntegrationPhaseBuildingKit) {
 		t.applyWhileBuildingKit(e)
+
 		return nil
 	}
 
@@ -304,6 +310,7 @@ func (t *quarkusTrait) newIntegrationKit(e *Environment, packageType quarkusPack
 	if e.Integration.Status.Capabilities != nil {
 		kit.Spec.Capabilities = e.Integration.Status.Capabilities
 	}
+
 	return kit
 }
 
@@ -311,19 +318,19 @@ func propagateKitTraits(e *Environment) v1.IntegrationKitTraits {
 	kitTraits := v1.IntegrationKitTraits{}
 
 	if e.Platform != nil {
-		propagate(fmt.Sprintf("platform %q", e.Platform.Name), e.Platform.Status.Traits, &kitTraits, e)
+		propagate(fmt.Sprintf("platform %q", e.Platform.Name), e.Platform.Status.Traits, &kitTraits)
 	}
 
 	if e.IntegrationProfile != nil {
-		propagate(fmt.Sprintf("integration profile %q", e.IntegrationProfile.Name), e.IntegrationProfile.Spec.Traits, &kitTraits, e)
+		propagate(fmt.Sprintf("integration profile %q", e.IntegrationProfile.Name), e.IntegrationProfile.Spec.Traits, &kitTraits)
 	}
 
-	propagate(fmt.Sprintf("integration %q", e.Integration.Name), e.Integration.Spec.Traits, &kitTraits, e)
+	propagate(fmt.Sprintf("integration %q", e.Integration.Name), e.Integration.Spec.Traits, &kitTraits)
 
 	return kitTraits
 }
 
-func propagate(traitSource string, traits v1.Traits, kitTraits *v1.IntegrationKitTraits, e *Environment) {
+func propagate(traitSource string, traits v1.Traits, kitTraits *v1.IntegrationKitTraits) {
 	ikt := v1.IntegrationKitTraits{
 		Builder: traits.Builder.DeepCopy(),
 		Camel:   traits.Camel.DeepCopy(),
@@ -333,19 +340,6 @@ func propagate(traitSource string, traits v1.Traits, kitTraits *v1.IntegrationKi
 	if err := kitTraits.Merge(ikt); err != nil {
 		log.Errorf(err, "Unable to propagate traits from %s to the integration kit", traitSource)
 	}
-
-	// propagate addons that influence kits too
-	if len(traits.Addons) > 0 {
-		if kitTraits.Addons == nil {
-			kitTraits.Addons = make(map[string]v1.AddonTrait)
-		}
-
-		for id, addon := range traits.Addons {
-			if t := e.Catalog.GetTrait(id); t != nil && t.InfluencesKit() {
-				kitTraits.Addons[id] = *addon.DeepCopy()
-			}
-		}
-	}
 }
 
 func (t *quarkusTrait) applyWhenBuildSubmitted(e *Environment) error {
@@ -441,6 +435,7 @@ func (t *quarkusTrait) isIncrementalImageBuild(e *Environment) bool {
 	// We need to get this information from the builder trait
 	if trait := e.Catalog.GetTrait(builderTraitID); trait != nil {
 		builder, ok := trait.(*builderTrait)
+
 		return ok && ptr.Deref(builder.IncrementalImageBuild, true)
 	}
 
@@ -474,8 +469,10 @@ func (t *quarkusTrait) isEmbedded(e *Environment, source v1.SourceSpec) bool {
 		return e.IntegrationKit != nil && t.isNativeIntegration(e) && sourcesRequiredAtBuildTime(e, source)
 	} else if e.IntegrationKitInPhase(v1.IntegrationKitPhaseBuildSubmitted) {
 		native, _ := t.isNativeKit(e)
+
 		return native && sourcesRequiredAtBuildTime(e, source)
 	}
+
 	return false
 }
 
@@ -485,6 +482,7 @@ func (t *quarkusTrait) containsMode(m traitv1.QuarkusMode) bool {
 			return true
 		}
 	}
+
 	return false
 }
 
@@ -502,6 +500,7 @@ func packageType(mode traitv1.QuarkusMode) quarkusPackageType {
 // Indicates whether the given source file is required at build time for native compilation.
 func sourcesRequiredAtBuildTime(e *Environment, source v1.SourceSpec) bool {
 	settings := getLanguageSettings(e, source.InferLanguage())
+
 	return settings.native && settings.sourcesRequiredAtBuildTime
 }
 
@@ -513,5 +512,6 @@ func propagateSourcesRequiredAtBuildTime(e *Environment) []v1.SourceSpec {
 			array = append(array, source)
 		}
 	}
+
 	return array
 }
