@@ -31,6 +31,7 @@ func init() {
 	AddToTraits(newEnvironmentTrait)
 	AddToTraits(newGCTrait)
 	AddToTraits(newGitTrait)
+	AddToTraits(newGitOpsTrait)
 	AddToTraits(newHealthTrait)
 	AddToTraits(newInitContainersTrait)
 	AddToTraits(NewInitTrait)
@@ -39,12 +40,12 @@ func init() {
 	AddToTraits(newJolokiaTrait)
 	AddToTraits(newJvmTrait)
 	AddToTraits(newKameletsTrait)
+	AddToTraits(newKedaTrait)
 	AddToTraits(newKnativeTrait)
 	AddToTraits(newKnativeServiceTrait)
 	AddToTraits(newLoggingTraitTrait)
 	AddToTraits(NewMasterTrait)
 	AddToTraits(newMountTrait)
-	AddToTraits(newOpenAPITrait)
 	AddToTraits(newOwnerTrait)
 	AddToTraits(newPdbTrait)
 	AddToTraits(newPlatformTrait)
