@@ -26,12 +26,11 @@ import (
 	"regexp"
 	"strings"
 
-	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
-
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/util"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/property"
 	"github.com/apache/camel-k/v2/pkg/util/sets"
 )
@@ -43,14 +42,6 @@ func (u Options) Get(id string) (map[string]interface{}, bool) {
 		return t, true
 	}
 
-	if addons, ok := u["addons"]; ok {
-		if addon, ok := addons[id]; ok {
-			if t, ok := addon.(map[string]interface{}); ok {
-				return t, true
-			}
-		}
-	}
-
 	return nil, false
 }
 
@@ -61,9 +52,8 @@ func getIntegrationKit(ctx context.Context, c client.Client, integration *v1.Int
 	if integration.Status.IntegrationKit == nil {
 		return nil, nil
 	}
-	kit := v1.NewIntegrationKit(integration.Status.IntegrationKit.Namespace, integration.Status.IntegrationKit.Name)
-	err := c.Get(ctx, ctrl.ObjectKeyFromObject(kit), kit)
-	return kit, err
+
+	return kubernetes.GetIntegrationKit(ctx, c, integration.Status.IntegrationKit.Name, integration.Status.IntegrationKit.Namespace)
 }
 
 func collectConfigurationPairs(configurationType string, configurable ...v1.Configurable) []variable {
@@ -91,6 +81,7 @@ func collectConfigurationPairs(configurationType string, configurable ...v1.Conf
 					if variable.Name == k {
 						result[i].Value = v
 						ok = true
+
 						break
 					}
 				}
@@ -130,6 +121,7 @@ func filterTransferableAnnotations(annotations map[string]string) map[string]str
 		}
 		res[k] = v
 	}
+
 	return res
 }
 
@@ -241,6 +233,7 @@ func getBuilderTask(tasks []v1.Task) *v1.BuilderTask {
 			return tasks[i].Builder
 		}
 	}
+
 	return nil
 }
 
@@ -250,6 +243,7 @@ func getPackageTask(tasks []v1.Task) *v1.BuilderTask {
 			return tasks[i].Package
 		}
 	}
+
 	return nil
 }
 
@@ -376,6 +370,7 @@ func extractAsArray(value string) []string {
 			}
 			arrayValue = append(arrayValue, prop)
 		}
+
 		return arrayValue
 	}
 
@@ -409,7 +404,7 @@ func NewSpecTraitsOptionsForIntegrationAndPlatform(
 	// IMPORTANT: when we remove this we'll need to remove the client.Client from the func,
 	// which will bring to more cascade removal. It had to be introduced to support the deprecated feature
 	// in a properly manner (ie, comparing the spec.traits with annotations in a proper way).
-	return newTraitsOptions(c, options, i.ObjectMeta.Annotations)
+	return newTraitsOptions(c, options, i.Annotations)
 }
 
 func NewSpecTraitsOptionsForIntegration(c client.Client, i *v1.Integration) (Options, error) {
@@ -422,7 +417,7 @@ func NewSpecTraitsOptionsForIntegration(c client.Client, i *v1.Integration) (Opt
 	// IMPORTANT: when we remove this we'll need to remove the client.Client from the func,
 	// which will bring to more cascade removal. It had to be introduced to support the deprecated feature
 	// in a properly manner (ie, comparing the spec.traits with annotations in a proper way).
-	return newTraitsOptions(c, m1, i.ObjectMeta.Annotations)
+	return newTraitsOptions(c, m1, i.Annotations)
 }
 
 func newTraitsOptionsForIntegrationKit(c client.Client, i *v1.IntegrationKit, traits v1.IntegrationKitTraits) (Options, error) {
@@ -435,7 +430,7 @@ func newTraitsOptionsForIntegrationKit(c client.Client, i *v1.IntegrationKit, tr
 	// IMPORTANT: when we remove this we'll need to remove the client.Client from the func,
 	// which will bring to more cascade removal. It had to be introduced to support the deprecated feature
 	// in a properly manner (ie, comparing the spec.traits with annotations in a proper way).
-	return newTraitsOptions(c, m1, i.ObjectMeta.Annotations)
+	return newTraitsOptions(c, m1, i.Annotations)
 }
 
 func NewSpecTraitsOptionsForIntegrationKit(c client.Client, i *v1.IntegrationKit) (Options, error) {
@@ -445,7 +440,15 @@ func NewSpecTraitsOptionsForIntegrationKit(c client.Client, i *v1.IntegrationKit
 func NewTraitsOptionsForPipe(c client.Client, pipe *v1.Pipe) (Options, error) {
 	options := Options{}
 
-	return newTraitsOptions(c, options, pipe.ObjectMeta.Annotations)
+	if pipe.Spec.Traits != nil {
+		var err error
+		options, err = ToTraitMap(*pipe.Spec.Traits)
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	return newTraitsOptions(c, options, pipe.Annotations)
 }
 
 // HasMatchingTraits verifies if two traits options match.
