@@ -18,11 +18,12 @@ limitations under the License.
 package bindings
 
 import (
+	"errors"
 	"fmt"
 
 	camelv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/apis/duck/strimzi/v1beta2"
-	"github.com/apache/camel-k/v2/pkg/client/duck/strimzi/clientset/internalclientset"
+	"github.com/apache/camel-k/v2/pkg/client/strimzi/clientset/internalclientset"
 	"github.com/apache/camel-k/v2/pkg/util/uri"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -66,7 +67,7 @@ func (s StrimziBindingProvider) Translate(ctx BindingContext, _ EndpointContext,
 	if err != nil {
 		return nil, err
 	}
-	kafkaURI := fmt.Sprintf("kafka:%s", camelKafka.topicName)
+	kafkaURI := "kafka:" + camelKafka.topicName
 	kafkaURI = uri.AppendParameters(kafkaURI, camelKafka.properties)
 
 	return &Binding{
@@ -93,10 +94,11 @@ func (s StrimziBindingProvider) fromKafkaToCamel(ctx BindingContext, endpoint ca
 		return nil, err
 	}
 	if props == nil || props["topic"] == "" {
-		return nil, fmt.Errorf("invalid endpoint configuration: missing topic property")
+		return nil, errors.New("invalid endpoint configuration: missing topic property")
 	}
 	topicName := props["topic"]
 	delete(props, "topic")
+	//nolint:nestif
 	if props["brokers"] == "" {
 		// build the client if needed
 		if s.Client == nil {
@@ -106,7 +108,12 @@ func (s StrimziBindingProvider) fromKafkaToCamel(ctx BindingContext, endpoint ca
 			}
 			s.Client = kafkaClient
 		}
-		bootstrapServers, err := s.getBootstrapServers(ctx, endpoint.Ref.Name)
+		namespace := endpoint.Ref.Namespace
+		if namespace == "" {
+			namespace = ctx.Namespace
+		}
+
+		bootstrapServers, err := s.getBootstrapServers(ctx, endpoint.Ref.Name, namespace)
 		if err != nil {
 			return nil, err
 		}
@@ -162,7 +169,11 @@ func (s StrimziBindingProvider) lookupBootstrapServers(ctx BindingContext, endpo
 	if clusterName == "" {
 		return "", fmt.Errorf("no %q label defined on topic %s", v1beta2.StrimziKafkaClusterLabel, endpoint.Ref.Name)
 	}
-	bootstrapServers, err := s.getBootstrapServers(ctx, clusterName)
+	namespace := endpoint.Ref.Namespace
+	if namespace == "" {
+		namespace = ctx.Namespace
+	}
+	bootstrapServers, err := s.getBootstrapServers(ctx, clusterName, namespace)
 	if err != nil {
 		return "", err
 	}
@@ -170,8 +181,8 @@ func (s StrimziBindingProvider) lookupBootstrapServers(ctx BindingContext, endpo
 	return bootstrapServers, nil
 }
 
-func (s StrimziBindingProvider) getBootstrapServers(ctx BindingContext, clusterName string) (string, error) {
-	cluster, err := s.Client.KafkaV1beta2().Kafkas(ctx.Namespace).Get(ctx.Ctx, clusterName, v1.GetOptions{})
+func (s StrimziBindingProvider) getBootstrapServers(ctx BindingContext, clusterName, namespace string) (string, error) {
+	cluster, err := s.Client.KafkaV1beta2().Kafkas(namespace).Get(ctx.Ctx, clusterName, v1.GetOptions{})
 	if err != nil {
 		return "", err
 	}
@@ -190,8 +201,12 @@ func (s StrimziBindingProvider) getBootstrapServers(ctx BindingContext, clusterN
 }
 
 func (s StrimziBindingProvider) lookupTopic(ctx BindingContext, endpoint camelv1.Endpoint) (*v1beta2.KafkaTopic, error) {
+	namespace := endpoint.Ref.Namespace
+	if namespace == "" {
+		namespace = ctx.Namespace
+	}
 	// first check by KafkaTopic name
-	topic, err := s.Client.KafkaV1beta2().KafkaTopics(ctx.Namespace).Get(ctx.Ctx, endpoint.Ref.Name, v1.GetOptions{})
+	topic, err := s.Client.KafkaV1beta2().KafkaTopics(namespace).Get(ctx.Ctx, endpoint.Ref.Name, v1.GetOptions{})
 	if err != nil && !k8serrors.IsNotFound(err) {
 		return nil, err
 	}
@@ -200,12 +215,12 @@ func (s StrimziBindingProvider) lookupTopic(ctx BindingContext, endpoint camelv1
 	}
 
 	// if not found, then, look at the .status.topicName (it may be autogenerated)
-	topics, err := s.Client.KafkaV1beta2().KafkaTopics(ctx.Namespace).List(ctx.Ctx, v1.ListOptions{
+	topics, err := s.Client.KafkaV1beta2().KafkaTopics(namespace).List(ctx.Ctx, v1.ListOptions{
 		FieldSelector: "status.topicName=" + endpoint.Ref.Name,
 	})
 
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("couldn't find any KafkaTopic with either name or topicName %s; error %w", endpoint.Ref.Name, err)
 	}
 	if len(topics.Items) == 0 {
 		return nil, fmt.Errorf("couldn't find any KafkaTopic with either name or topicName %s", endpoint.Ref.Name)
