@@ -18,7 +18,7 @@ limitations under the License.
 package knative
 
 import (
-	knativev1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/knative"
+	knativev1 "github.com/apache/camel-k/v2/pkg/internal/knative"
 	"github.com/apache/camel-k/v2/pkg/util"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -137,6 +137,7 @@ var (
 // GroupVersionKindResource --.
 type GroupVersionKindResource struct {
 	schema.GroupVersionKind
+
 	Resource string
 }
 
@@ -172,6 +173,7 @@ func GetServiceType(ref v1.ObjectReference) (*knativev1.CamelServiceType, error)
 	for _, c := range KnownChannelKinds {
 		if c.Group == refGV.Group && c.Kind == ref.Kind {
 			channelType := knativev1.CamelServiceTypeChannel
+
 			return &channelType, nil
 		}
 	}
@@ -179,6 +181,7 @@ func GetServiceType(ref v1.ObjectReference) (*knativev1.CamelServiceType, error)
 	for _, c := range KnownBrokerKinds {
 		if c.Group == refGV.Group && c.Kind == ref.Kind {
 			eventType := knativev1.CamelServiceTypeEvent
+
 			return &eventType, nil
 		}
 	}
@@ -186,6 +189,7 @@ func GetServiceType(ref v1.ObjectReference) (*knativev1.CamelServiceType, error)
 	for _, c := range KnownEndpointKinds {
 		if c.Group == refGV.Group && c.Kind == ref.Kind {
 			endpointType := knativev1.CamelServiceTypeEndpoint
+
 			return &endpointType, nil
 		}
 	}
@@ -218,6 +222,7 @@ func fillMissingReferenceDataWith(serviceTypes []GroupVersionKindResource, ref v
 	default:
 		list = append(list, ref)
 	}
+
 	return list
 }
 
@@ -228,6 +233,7 @@ func getGroupVersions(serviceTypes []GroupVersionKindResource, kind string) []st
 			util.StringSliceUniqueAdd(&res, st.GroupVersion().String())
 		}
 	}
+
 	return res
 }
 
@@ -238,5 +244,6 @@ func getKinds(serviceTypes []GroupVersionKindResource, apiVersion string) []stri
 			util.StringSliceUniqueAdd(&res, st.Kind)
 		}
 	}
+
 	return res
 }
