@@ -20,7 +20,7 @@ package knative
 import (
 	"testing"
 
-	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/knative"
+	"github.com/apache/camel-k/v2/pkg/internal/knative"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	v1 "k8s.io/api/core/v1"
